summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/kcautoconfigmodule.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/libkopete/kcautoconfigmodule.h')
-rw-r--r--kopete/libkopete/kcautoconfigmodule.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kopete/libkopete/kcautoconfigmodule.h b/kopete/libkopete/kcautoconfigmodule.h
index 1fe15acf..91ce9886 100644
--- a/kopete/libkopete/kcautoconfigmodule.h
+++ b/kopete/libkopete/kcautoconfigmodule.h
@@ -63,18 +63,18 @@ class KOPETE_EXPORT KCAutoConfigModule : public KCModule
/**
* Standard KCModule constructor. Use KGlobal::config()
*/
- KCAutoConfigModule( KInstance * instance, TQWidget * parent = 0, const TQStringList & args = TQStringList() );
+ KCAutoConfigModule( TDEInstance * instance, TQWidget * parent = 0, const TQStringList & args = TQStringList() );
/**
* Constructor.
* @param config the KConfig to use
* @param instance KInstance object for this KCM
* @param parent parent widget
* @param args special arguments for this KCM
*
* @todo document what the args mean (inherited from KCModule?)
*/
- KCAutoConfigModule(KConfig* config, KInstance * instance, TQWidget * parent = 0, const TQStringList & args = TQStringList() );
+ KCAutoConfigModule(KConfig* config, TDEInstance * instance, TQWidget * parent = 0, const TQStringList & args = TQStringList() );
/**
* Constructor, much like the one above, except with
@@ -63,18 +63,18 @@ class KOPETE_EXPORT KCAutoConfigModule : public KCModule
* Constructor.
* @param config the KConfig to use
- * @param instance KInstance object for this KCM
+ * @param instance TDEInstance object for this KCM
* @param parent parent widget
* @param args special arguments for this KCM